Class: ICU4X::DataGenerator
- Inherits:
-
Object
- Object
- ICU4X::DataGenerator
- Defined in:
- lib/icu4x/yard_docs.rb
Overview
Generates locale data blobs for use with DataProvider.
DataGenerator exports Unicode CLDR data into a compact binary format that can be loaded at runtime by DataProvider.
Class Method Summary collapse
-
.available_markers ⇒ Array<String>
Returns a list of all available data marker names.
-
.export(locales:, markers:, format:, output:) ⇒ void
Exports locale data to a file.
Class Method Details
.available_markers ⇒ Array<String>
Returns a list of all available data marker names.
156 |
# File 'lib/icu4x/yard_docs.rb', line 156 def self.available_markers; end |
.export(locales:, markers:, format:, output:) ⇒ void
This method returns an undefined value.
Exports locale data to a file.
The ‘locales` parameter accepts either a Symbol for predefined locale sets based on CLDR coverage levels, or an Array of locale identifier strings. When using `with_descendants`, ancestor locales (including `und`) are automatically included for fallback support.
146 |
# File 'lib/icu4x/yard_docs.rb', line 146 def self.export(locales:, markers:, format:, output:); end |