Class: ICU4X::Segmenter::Segment
- Inherits:
-
Data
- Object
- Data
- ICU4X::Segmenter::Segment
- Defined in:
- lib/icu4x.rb,
lib/icu4x.rb,
lib/icu4x/yard_docs.rb
Overview
Represents a segment of text.
Instance Attribute Summary collapse
-
#index ⇒ Integer
readonly
The byte index of this segment in the original string.
-
#segment ⇒ String
readonly
The segment text.
Instance Attribute Details
#index ⇒ Integer (readonly)
Returns the byte index of this segment in the original string.
82 83 84 |
# File 'lib/icu4x.rb', line 82 def index @index end |
#segment ⇒ String (readonly)
Returns the segment text.
82 83 84 |
# File 'lib/icu4x.rb', line 82 def segment @segment end |